@@ -1,7 +1,11 @@
-// Copyright 2011-2021 David Robillard <d@drobilla.net>
+// Copyright 2011-2024 David Robillard <d@drobilla.net>
 // SPDX-License-Identifier: ISC
 
-#include "zix/btree.h"
+#include <zix/btree.h>
+
+#include <zix/allocator.h>
+#include <zix/attributes.h>
+#include <zix/status.h>
 
 #include <assert.h>
 #include <stdint.h>
@@ -78,8 +82,7 @@ zix_btree_node_new(ZixAllocator* const allocator, const bool leaf)
   return node;
 }
 
-ZIX_PURE_FUNC
-static ZixBTreeNode*
+ZIX_PURE_FUNC static ZixBTreeNode*
 zix_btree_child(const ZixBTreeNode* const node, const unsigned i)
 {
   assert(!node->is_leaf);
@@ -196,7 +199,7 @@ zix_btree_ainsert(void** const   array,
                   const unsigned i,
                   void* const    e)
 {
-  memmove(array + i + 1U, array + i, (n - i) * sizeof(e));
+  memmove(array + i + 1U, array + i, ((size_t)n - i) * sizeof(e));
   array[i] = e;
 }
 
@@ -205,7 +208,7 @@ static void*
 zix_btree_aerase(void** const array, const unsigned n, const unsigned i)
 {
   void* const ret = array[i];
-  memmove(array + i, array + i + 1U, (n - i) * sizeof(ret));
+  memmove(array + i, array + i + 1U, ((size_t)n - i) * sizeof(ret));
   return ret;
 }
 
@@ -247,7 +250,7 @@ zix_btree_split_child(ZixAllocator* const allocator,
            rhs->n_vals * sizeof(void*));
     memcpy(rhs->data.inode.children,
            lhs->data.inode.children + lhs->n_vals + 1U,
-           (rhs->n_vals + 1U) * sizeof(ZixBTreeNode*));
+           ((size_t)rhs->n_vals + 1U) * sizeof(ZixBTreeNode*));
 
     // Move middle value up to parent
     zix_btree_ainsert(
@@ -394,14 +397,14 @@ zix_btree_leaf_find(const ZixBTree* const     t,
     t->cmp, t->cmp_data, n->data.leaf.vals, n->n_vals, e, equal);
 }
 
-static inline bool
+ZIX_PURE_FUNC static inline bool
 zix_btree_can_remove_from(const ZixBTreeNode* const n)
 {
   assert(n->n_vals >= zix_btree_min_vals(n));
   return n->n_vals > zix_btree_min_vals(n);
 }
 
-static inline bool
+ZIX_PURE_FUNC static inline bool
 zix_btree_is_full(const ZixBTreeNode* const n)
 {
   assert(n->n_vals <= zix_btree_max_vals(n));
@@ -617,7 +620,7 @@ zix_btree_merge(ZixBTree* const t, ZixBTreeNode* const n, const unsigned i)
            rhs->n_vals * sizeof(void*));
     memcpy(lhs->data.inode.children + lhs->n_vals,
            rhs->data.inode.children,
-           (rhs->n_vals + 1U) * sizeof(void*));
+           ((size_t)rhs->n_vals + 1U) * sizeof(void*));
   }
 
   lhs->n_vals += rhs->n_vals;
@@ -677,6 +680,7 @@ zix_btree_fatten_child(ZixBTree* const t, ZixBTreeIter* const iter)
 
   assert(n);
   assert(!n->is_leaf);
+  assert(n->n_vals);
   ZixBTreeNode* const* const children = n->data.inode.children;
 
   if (i > 0U && zix_btree_can_remove_from(children[i - 1U])) {
@@ -959,7 +963,7 @@ zix_btree_end(const ZixBTree* const t)
 bool
 zix_btree_iter_equals(const ZixBTreeIter lhs, const ZixBTreeIter rhs)
 {
-  const size_t indexes_size = (lhs.level + 1U) * sizeof(uint16_t);
+  const size_t indexes_size = ((size_t)lhs.level + 1U) * sizeof(uint16_t);
 
   return (lhs.level == rhs.level) && (lhs.nodes[0U] == rhs.nodes[0U]) &&
          (!lhs.nodes[0U] || !memcmp(lhs.indexes, rhs.indexes, indexes_size));
