@@ -1,9 +1,9 @@
 // Copyright 2012-2022 David Robillard <d@drobilla.net>
 // SPDX-License-Identifier: ISC
 
-#include "zix/thread.h"
+#include <zix/thread.h>
 
-#include "zix/status.h"
+#include <zix/status.h>
 
 #include <windows.h>
 
